@@ -8,9 +8,17 @@ Copyright (c) 2012 Multmeio [design+tecnologia]. All rights reserved.
 """
 
 from django.template.defaultfilters import slugify
+from ast import literal_eval
 
-__all__ = ['single_list_to_tuple']
+__all__ = ['single_list_to_tuple',
+           'str2literal',]
 
 
 def single_list_to_tuple(list_values):
     return [(v, v) for v in list_values]
+
+def str2literal(string):
+    try:
+        return literal_eval(string)
+    except:
+        return ''
